@@ -60,7 +60,7 @@ def test_highlight_not_found_log(finder: FinderPage, listener: Listener, caplog)
 
     assert len(caplog.records) == 1
     for record in caplog.records:
-        assert "Cannot highlight UiElement(By.css selector(#inexistent))[0]: Not found" in record.message
+        assert "Cannot highlight UiElement(By.css selector(#inexistent))[0]: Element not found" in record.message
 
 
 def teardown_module():
